@@ -7,11 +7,14 @@
 from talos.thrift.auth.ttypes import Credential
 from talos.thrift.auth import constants
 from talos.thrift.transport.TTransport import TTransportBase
-from talos.thrift.common.ttypes import GalaxyTalosException
+from talos.client.TalosErrors import TalosTransportError
+from talos.client.TalosErrors import HttpStatusCode
 from io import BytesIO
 from datetime import datetime
 from six.moves import urllib
 from six.moves import http_client
+from talos.utils.Utils import current_time_mills
+import re
 import six
 import time
 import hashlib
@@ -398,16 +401,42 @@ class TalosHttpClient(TTransportBase):
 
         # Get reply to flush the request
         self.__http_response = self.__http.getresponse()
-        response = self.__http_response
         self.code = self.__http_response.status
-        self.message = self.__http_response.reason
-        self._headers = self.__http_response.msg
+        response = self.__http_response
         if not self.code == 200:
-            raise GalaxyTalosException(errorCode=self.code, errMsg=self.message)
-            # pass
-        # TODO Trans Exception to TalosTransportError
-        # reason = response.fp.read()
-        # raise TalosTransportError(self.code, self.message, current_time_mills())
+            isTalosTransportError = True
+            headers = response.headers._headers
+            for i in headers:
+                if i[0] == 'Content-Type':
+                    isTalosTransportError = False
+                    if not re.match('application/x-thrift', i[1]):
+                        isTalosTransportError = True
+
+            if isTalosTransportError:
+                self.adjustClock(response, self.code)
+                raise TalosTransportError(self.code, response.reason,
+                                          current_time_mills())
+
+    # Adjust local clock when clock skew error received from server.The client clock need to be
+    # roughly synchronized with server clock to make signature secure
+    # and reduce the chance of replay attacks.
+    # @ param response server response
+    # @ param httpStatusCode status code
+    # @ return if clock is adjusted
+    def adjustClock(self, response, httpStatusCode):
+        if httpStatusCode == HttpStatusCode.CLOCK_TOO_SKEWED:
+            headers = response.heasers(constants.HK_TIMESTAMP)
+            for key, hv in headers.items():
+                serverTime = int(hv)
+                min = 60 * 60 * 24 * 365 * (2010 - 1970)
+                max = 60 * 60 * 24 * 365 * (2030 - 1970)
+            if serverTime > min and serverTime < max:
+                self.logger.debug("Adjusting client time from {} to {}" +
+                                  str(self._clockOffset) + " serverTime: " + str(
+                    serverTime))
+                self._clockOffset = serverTime
+                return True
+        return False
 
     def generate_random_id(self, length=None):
         return str(uuid.uuid4())[0:length]
